/**
 * BLOCK: gbmp
 *
 * Registering a basic block with Gutenberg.
 * Simple block, renders and saves the same content without any interactivity.
 */

//  Import CSS.
import './editor.scss';
import './style.scss';

const { __ } = wp.i18n;
const { registerBlockType } = wp.blocks;
const { InnerBlocks } = wp.blockEditor;
const { useState } = wp.element;
const { select } = wp.data;

function moveBlocksToDesktop( desktopId, parentID ) {
	wp.data.dispatch( "core/block-editor" ).moveBlocksToPosition(
		wp.data.select( "core/block-editor" ).getBlockOrder().filter( id => id !== parentID ),
		'',
		desktopId
	);
}

function copyFromDesktopToMobile( mobId, desktopId ) {
	const desktopBlockIds = wp.data.select( "core/block-editor" ).getBlockOrder( desktopId );
	wp.data.dispatch( "core/block-editor" ).duplicateBlocks( desktopBlockIds )
		.then( blocks => {
			wp.data.dispatch( "core/block-editor" ).moveBlocksToPosition( blocks, desktopId, mobId );
		} );
}

/**
 * Register: aa Gutenberg Block.
 *
 * Registers a new block provided a unique name and an object defining its
 * behavior. Once registered, the block is made editor as an option to any
 * editor interface where blocks are implemented.
 *
 * @link https://wordpress.org/gutenberg/handbook/block-api/
 * @param  {string}   name     Block name.
 * @param  {Object}   settings Block settings.
 * @return {?WPBlock}          The block, if it has been successfully
 *                             registered; otherwise `undefined`.
 */
registerBlockType( 'gbmp/desktop-mobile', {
	// Block name. Block names must be string that contains a namespace prefix. Example: my-plugin/my-custom-block.
	title      : __( 'Gutenberg Mobile' ), // Block title.
	description: <div>Shows content only on Mobile devices. Check out <a href='https://www.pootlepress.com/gutenberg-mobile-pages-pro'>Mobile Pages Pro</a> for more flexible layouts.</div>,
	icon       : 'welcome-view-site', // Block icon from Dashicons → https://developer.wordpress.org/resource/dashicons/.
	category   : 'layout', // Block category — Group blocks together based on common traits E.g. common, formatting, layout widgets, embed.
	keywords   : [
		__( 'Mobile layout' ),
		__( 'Tablet Layout' ),
		__( 'Desktop Layout' ),
		__( 'iPhone' ),
		__( 'iPad' ),
	],

	edit: ( props ) => {
		const [ tabActive, tabToggle ] = useState( 'desktop' );
		const [ desktopId, mobId ] = select("core/block-editor").getBlockOrder( props.clientId )
		// Creates a <p class='wp-block-cgb-block-gbmp'></p>.
		const innerBlkProps = {
			template    : [
				['gbmp/desktop'],
				['gbmp/mobile'],
			],
			templateLock: 'all',
		};

		window.props = props;
		window.desktopId = desktopId;
		window.mobId = mobId;
		return (
			<div data-gbmp-type='desktop-mobile-split' data-gbmp-active={tabActive} className={'gbmp-split ' + props.className}>
				<div className="components-panel__header interface-complementary-area-header edit-post-sidebar__panel-tabs">
					{gbmpSplitBlockTabs( {tabActive, tabToggle} )}
					{tabActive === 'desktop' &&
					 <button type="button" aria-disabled="false" onClick={e => moveBlocksToDesktop( desktopId, props.clientId )}
									 className="components-button is-secondary ml-auto">
						 Import page content
					 </button>}
					{tabActive === 'mobile' &&
					 <button type="button" aria-disabled="false" onClick={e => copyFromDesktopToMobile( mobId, desktopId )}
									 className="components-button is-secondary ml-auto">
						 Copy from Desktop content
					 </button>}
				</div>
				<InnerBlocks {...innerBlkProps} />
			</div>
		);
	},

	save: ( props ) => {
		return (
			<div className={props.className}>
				<div className="gbmp-mobile-desktop">
					<InnerBlocks.Content/>
				</div>
			</div>
		);
	},
} );

function gbmpSplitBlockTabs( {tabToggle, tabActive} ) {
	const tabBtnBaseClass = "components-button edit-post-sidebar__panel-tab ";
	function toggle( tab ) {
		return e => tabToggle( tab );
	}
	return <ul className="gbmp-tabs">
			<li>
				<button type="button" aria-label="Desktop" data-label="Page" onClick={toggle( 'desktop' )}
								className={tabBtnBaseClass + (tabActive === 'desktop' ? 'is-active' : '')}>
					Desktop content
				</button>
			</li>
			<li>
				<button type="button" aria-label="Mobile" data-label="Block" onClick={toggle( 'mobile' )}
								className={tabBtnBaseClass + (tabActive === 'mobile' ? 'is-active' : '')}>
					Mobile content
				</button>
			</li>
		</ul>;
}
